@@ -41,6 +41,7 @@ static const gchar *gconf_fullscreen_active_key = "fullscreen_active";
 static const gchar *gconf_init_active_key = "init_active";
 static const gchar *gconf_dsme_active_key = "dsme_active";
 static const gchar *gconf_alarm_event_key = "alarm_event";
+static const gchar *gconf_alarm_reboot_key = "alarm_reboot";
 static const alarm_event_t alarm_template = {0, 1440, -1, 0,
                                              NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL,
                                              "/etc/cron.daily/skype-autolauncher",
@@ -51,11 +52,13 @@ static const gchar *init_script = "/etc/init.d/x-skype-autolauncher";
 static void _get_gconf_settings (gboolean *fullscreen_active,
                                  gboolean *init_active,
                                  gboolean *dsme_active,
-                                 gint *alarm_event);
+                                 gint *alarm_event,
+                                 gboolean *alarm_reboot);
 static void _set_gconf_settings (gboolean fullscreen_active,
                                  gboolean init_active,
                                  gboolean dsme_active,
-                                 gint alarm_event);
+                                 gint alarm_event,
+                                 gboolean alarm_reboot);
 static void _activate_associated_widget_to_toggle_toggled (GtkToggleButton *toggle_button,
                                                            GtkWidget *widget);
 static gboolean _compare_alarm_events (alarm_event_t *first_event,
@@ -72,6 +75,7 @@ static GtkDialog* _skype_autolauncher_dialog_new (GtkWidget **fullscreen_check,
                                                   GtkWidget **init_check,
                                                   GtkWidget **dsme_check,
                                                   GtkWidget **alarm_check,
+                                                  GtkWidget **reboot_check,
                                                   GtkWidget **alarm_time_editor);
 static void _skype_autolauncher_dialog_show ();
 
@@ -95,17 +99,20 @@ static void
 _get_gconf_settings (gboolean *fullscreen_active,
                      gboolean *init_active,
                      gboolean *dsme_active,
-                     gint *alarm_event)
+                     gint *alarm_event,
+                     gboolean *alarm_reboot)
 {
     GConfClient *client = NULL;
     GConfEntry *fullscreen_active_entry = NULL;
     GConfEntry *init_active_entry = NULL;
     GConfEntry *dsme_active_entry = NULL;
     GConfEntry *alarm_event_entry = NULL;
+    GConfEntry *alarm_reboot_entry = NULL;
     GConfValue *fullscreen_active_value = NULL;
     GConfValue *init_active_value = NULL;
     GConfValue *dsme_active_value = NULL;
     GConfValue *alarm_event_value = NULL;
+    GConfValue *alarm_reboot_value = NULL;
     gchar *tmp_string = NULL;
 
 
@@ -113,6 +120,7 @@ _get_gconf_settings (gboolean *fullscreen_active,
     g_assert (NULL != init_active);
     g_assert (NULL != dsme_active);
     g_assert (NULL != alarm_event);
+    g_assert (NULL != alarm_reboot);
 
 
     client = gconf_client_get_default ();
@@ -163,6 +171,16 @@ _get_gconf_settings (gboolean *fullscreen_active,
                                                 NULL);
     g_free (tmp_string);
 
+    tmp_string = g_strdup_printf ("%s/%s",
+                                  gconf_skype_autolauncher_path,
+                                  gconf_alarm_reboot_key);
+    alarm_reboot_entry = gconf_client_get_entry (client,
+                                                tmp_string,
+                                                NULL,
+                                                TRUE,
+                                                NULL);
+    g_free (tmp_string);
+
     fullscreen_active_value = gconf_entry_get_value (fullscreen_active_entry);
 
     if (NULL != fullscreen_active_value) {
@@ -187,6 +205,12 @@ _get_gconf_settings (gboolean *fullscreen_active,
         *alarm_event = gconf_value_get_int (alarm_event_value);
     }
 
+    alarm_reboot_value = gconf_entry_get_value (alarm_reboot_entry);
+
+    if (NULL != alarm_reboot_value) {
+        *alarm_reboot = gconf_value_get_bool (alarm_reboot_value);
+    }
+
 
 cleanup:
 
@@ -202,6 +226,9 @@ cleanup:
     if (NULL != alarm_event_entry) {
         gconf_entry_unref (alarm_event_entry);
     }
+    if (NULL != alarm_reboot_entry) {
+        gconf_entry_unref (alarm_reboot_entry);
+    }
     g_object_unref (client);
 }
 
@@ -210,7 +237,8 @@ static void
 _set_gconf_settings (gboolean fullscreen_active,
                      gboolean init_active,
                      gboolean dsme_active,
-                     gint alarm_event)
+                     gint alarm_event,
+                     gboolean alarm_reboot)
 {
     GConfClient *client = NULL;
     gchar *tmp_string = NULL;
@@ -254,6 +282,15 @@ _set_gconf_settings (gboolean fullscreen_active,
                            NULL);
     g_free (tmp_string);
 
+    tmp_string = g_strdup_printf ("%s/%s",
+                                  gconf_skype_autolauncher_path,
+                                  gconf_alarm_reboot_key);
+    gconf_client_set_bool (client,
+                           tmp_string,
+                           alarm_reboot,
+                           NULL);
+    g_free (tmp_string);
+
 
 /* cleanup: */
 
@@ -502,6 +539,7 @@ _skype_autolauncher_dialog_new (GtkWidget **fullscreen_check,
                                 GtkWidget **init_check,
                                 GtkWidget **dsme_check,
                                 GtkWidget **alarm_check,
+                                GtkWidget **reboot_check,
                                 GtkWidget **alarm_time_editor)
 {
     GtkWidget *dialog = NULL;
@@ -513,6 +551,7 @@ _skype_autolauncher_dialog_new (GtkWidget **fullscreen_check,
     g_assert (NULL != init_check);
     g_assert (NULL != dsme_check);
     g_assert (NULL != alarm_check);
+    g_assert (NULL != reboot_check);
     g_assert (NULL != alarm_time_editor);
 
 
@@ -530,16 +569,20 @@ _skype_autolauncher_dialog_new (GtkWidget **fullscreen_check,
     *init_check = gtk_check_button_new ();
     *dsme_check = gtk_check_button_new ();
     *alarm_check = gtk_check_button_new ();
+    *reboot_check = gtk_check_button_new ();
     *alarm_time_editor = hildon_time_editor_new ();
 
     g_signal_connect (G_OBJECT (*init_check), "toggled",
                       G_CALLBACK (_activate_associated_widget_to_toggle_toggled),
                       *dsme_check);
+    g_signal_connect (G_OBJECT (*alarm_check), "toggled",
+                      G_CALLBACK (_activate_associated_widget_to_toggle_toggled),
+                      *reboot_check);
     g_signal_connect (G_OBJECT (*alarm_check), "toggled",
                       G_CALLBACK (_activate_associated_widget_to_toggle_toggled),
                       *alarm_time_editor);
 
-    table = gtk_table_new (5, 3, FALSE);
+    table = gtk_table_new (6, 3, FALSE);
     gtk_container_add (GTK_CONTAINER (GTK_DIALOG (dialog)->vbox), table);
     alignment = gtk_alignment_new (0, 0, 0, 0);
     gtk_container_add (GTK_CONTAINER (alignment), *init_check);
@@ -578,17 +621,27 @@ _skype_autolauncher_dialog_new (GtkWidget **fullscreen_check,
     gtk_table_attach_defaults (GTK_TABLE (table),
                                alignment,
                                0, 1, 3, 4);
-    label = gtk_label_new ("Restart Skype automatically every day at a given "
+    label = gtk_label_new ("Re-start Skype automatically every day at a given "
                            "time?");
     gtk_misc_set_alignment (GTK_MISC (label), 0, 0);
     gtk_table_attach_defaults (GTK_TABLE (table),
                                label,
                                1, 3, 3, 4);
     alignment = gtk_alignment_new (0, 0, 0, 0);
+    gtk_container_add (GTK_CONTAINER (alignment), *reboot_check);
+    gtk_table_attach_defaults (GTK_TABLE (table),
+                               alignment,
+                               1, 2, 4, 5);
+    label = gtk_label_new ("Re-start the device instead of just Skype?");
+    gtk_misc_set_alignment (GTK_MISC (label), 0, 0);
+    gtk_table_attach_defaults (GTK_TABLE (table),
+                               label,
+                               2, 3, 4, 5);
+    alignment = gtk_alignment_new (0, 0, 0, 0);
     gtk_container_add (GTK_CONTAINER (alignment), *alarm_time_editor);
     gtk_table_attach_defaults (GTK_TABLE (table),
                                alignment,
-                               1, 3, 4, 5);
+                               1, 3, 5, 6);
     gtk_widget_show_all (dialog);
 
     return GTK_DIALOG (dialog);
@@ -603,11 +656,13 @@ _skype_autolauncher_dialog_show ()
     GtkWidget *init_check = NULL;
     GtkWidget *dsme_check = NULL;
     GtkWidget *alarm_check = NULL;
+    GtkWidget *reboot_check = NULL;
     GtkWidget *alarm_time_editor = NULL;
     gboolean fullscreen_active = TRUE;
     gboolean init_active = TRUE;
     gboolean dsme_active = TRUE;
     gboolean alarm_active = FALSE;
+    gboolean alarm_reboot = FALSE;
     gint orig_alarm_event = 0;
     gint alarm_event = 0;
     guint hours;
@@ -620,12 +675,14 @@ _skype_autolauncher_dialog_show ()
                                                          &init_check,
                                                          &dsme_check,
                                                          &alarm_check,
+                                                         &reboot_check,
                                                          &alarm_time_editor));
 
     _get_gconf_settings (&fullscreen_active,
                          &init_active,
                          &dsme_active,
-                         &orig_alarm_event);
+                         &orig_alarm_event,
+                         &alarm_reboot);
 
     alarm_event = orig_alarm_event;
 
@@ -644,6 +701,8 @@ _skype_autolauncher_dialog_show ()
                                              &minutes,
                                              &seconds);
 
+    gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (reboot_check),
+                                  alarm_reboot);
     gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (fullscreen_check),
                                   fullscreen_active);
     gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (dsme_check),
@@ -662,6 +721,8 @@ _skype_autolauncher_dialog_show ()
             gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (dsme_check));
         gboolean new_alarm_active =
             gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (alarm_check));
+        gboolean new_alarm_reboot =
+            gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (reboot_check));
         guint new_hours;
         guint new_minutes;
         guint new_seconds;
@@ -713,7 +774,8 @@ _skype_autolauncher_dialog_show ()
 
         if ((alarm_active != new_alarm_active) ||
             (new_alarm_active &&
-             ((hours != new_hours) ||
+             ((alarm_reboot != new_alarm_reboot) ||
+              (hours != new_hours) ||
               (minutes != new_minutes) ||
               (seconds != new_seconds)))) {
             modified = TRUE;
@@ -730,7 +792,8 @@ _skype_autolauncher_dialog_show ()
             _set_gconf_settings (new_fullscreen_active,
                                  new_init_active,
                                  new_dsme_active,
-                                 new_alarm_event);
+                                 new_alarm_event,
+                                 new_alarm_reboot);
 
             if (restart_init) {
                 _restart_init ();
